@@ -5,10 +5,10 @@ from abc import ABC, abstractmethod
 from uuid import uuid1
 try:
     import pyarrow.plasma as plasma
-    from tx.parallex.plasma import start_plasma, stop_plasma
-except:
+    from .plasma import start_plasma, stop_plasma
+except ModuleNotFoundError as e:
     pass
-
+    
 
 logger = getLogger(__name__, logging.INFO)
 
